<div style="float: right">
<a href="https://badge.fury.io/py/kgen"><img src="https://badge.fury.io/py/kgen.svg" alt="PyPI version" height="18"></a>
</div>

# Kgen in Python

For details, see the [manual](https://palaeocarb.github.io/Kgen/use_kgen/python).